@@ -181,6 +181,8 @@ def add_command_line_options(add_argument, use_short_options=True):
                  action="append", default=[],
                  help="Use the specified credentials module to update "
                  "the values in okcupyd.settings.")
+    add_argument('--echo', dest='echo', action='store_true', default=False,
+                 help="Echo SQL.")
 
 
 def handle_command_line_options(args):
@@ -188,6 +190,10 @@ def handle_command_line_options(args):
         enable_logger(enabled_log)
     for credentials_module in args.credentials_modules:
         update_settings_with_module(credentials_module)
+    if args.echo:
+        from okcupyd import db
+        db.echo = True
+        db.Session.kw['echo'] = True
     return args
 
 
@@ -217,7 +223,7 @@ class Fetchable(object):
     def items(self):
         return list(self._fetcher.fetch())
 
-    def refresh(self, use_existing=True, stop_at=None):
+    def refresh(self, use_existing=False, stop_at=None):
         if 'items' in self.__dict__:
             self.items = list(self._fetcher.fetch(
                 id_to_existing=self.items if use_existing else ()
